#
# spec file for package python-paho-mqtt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-paho-mqtt
Version:        1.4.0
Release:        3.1
Summary:        MQTT version 3.11 client class
License:        EPL-1.0
Group:          Development/Languages/Python
Url:            http://eclipse.org/paho
Source:         https://files.pythonhosted.org/packages/source/p/paho-mqtt/paho-mqtt-%{version}.tar.gz
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This code provides a client class which enable applications to connect to an
MQTT broker to publish messages, and to subscribe to topics and receive
published messages. It also provides some helper functions to make publishing
one off messages to an MQTT server very straightforward.

The MQTT protocol is a machine-to-machine (M2M)/"Internet of Things"
connectivity protocol. Designed as an extremely lightweight publish/subscribe
messaging transport, it is useful for connections with remote locations where
a small code footprint is required and/or network bandwidth is at a premium.

Paho is an Eclipse Foundation project.

%prep
%setup -q -n paho-mqtt-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %python_files
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Mon Dec 10 2018 tchvatal@suse.com
- Fix fdupes call
* Sun Sep  2 2018 antoine.belvire@opensuse.org
- Update to version 1.4.0:
  * Fix hang when client restarted and broker resumed a session
    with Qos2 message.
  * Fix reconnection loop when a clean_session=True client
    reconnect while Qos2 message are being sent.
  * Catch and log any exception raised by user callback.
  * Improve support for external event loop (like asyncio).
  * Fix order of message with publish.multiple helper.
  * Fix hang on wait_for_published() on bad network.
  * Fix issue with Websocket payload size between 127 and 65536.
  * Closes socket in client destructor to avoid FD leak.
  * Fix uncaught timeout exception during connection.
  * Remove dup flag on PUBREL packet.
  * Use secure entropy source for Websocket mask_key (urandom).
  * Fix mid generation that was not thread-safe.
  * Replace print() statements with proper logging.
  * Allow insecure TLS on publish and subscribe helpers.
  * Allow to remove authentication (reset username to None).
  * Add support for the non-standard bridge mode.
* Sat Nov 18 2017 antoine.belvire@opensuse.org
- Update to version 1.3.1:
  * Fix reconnect_delay_set which ignored the max_delay.
  * Fix crash when connection is lost while trying to send message.
  * Fix issue with unicode topic when some character were
    multi-bytes UTF-8.
  * Fix issue with empty Client ID with broker that doesn't support
    them.
  * Fix issue with tls_set that did not allowed
    cert_reqs=ssl.CERT_NONE.
* Sat Jul  8 2017 antoine.belvire@opensuse.org
- Update to version 1.3.0:
  * Requires Python 2.7 or 3.4+.
  * Remove support for SSL without SSLContext (Requires Python
    2.7.9+ or 3.2+).
  * on_connect callback is now always called flags. Previously this
  * callback could accepts 3 OR 4 arguments, now it must accepts 4.
  * tls_insecure_set() must now be called *after* tls_set().
  * Allow username and password to be zero length (as opposed to
  * not being present).
  * Allow zero length client ids when using MQTT v3.1.1.
  * Add SSLContext support, including SNI.
  * Improved support for unicode topic and binary payload.
  * Allow arbitrary Websocket headers and path.
  * Fix issue with large inbound payload over Websocket.
  * Add exponential delay for reconnection.
  * Move unit tests to pytest and tox.
  * Add support for standard Python logging.
  * Fix duplicate incoming QoS==2 message.
* Sat Apr 22 2017 antoine.belvire@opensuse.org
- Update to version 1.2.3:
  * Fix possible hang of TLS connection during handshake.
  * Fix issue with publish helper with TLS connection.
  * Fix installation issue on non-UTF-8 system.
  * Fix non-working Websocket over TLS connection.
- Remove paho-mqtt-1.2.2-fix-readme-decoding.patch (fixed
  upstream).
* Fri Apr 14 2017 antoine.belvire@opensuse.org
- Update to version 1.2.2:
  * Fix message lost when using paho.mqtt.publish helper with
    QoS=0 message.
- Changes from version 1.2.1:
  * Handle unicode username and passwords correctly.
  * Fix handling of invalid UTF-8 topics on incoming messages - the
    library now does not attempt to decode the topic - this will
    happen when the user accesses msg.topic in the on_message
    callback. If the topic is not valid UTF-8, an exception will be
    raised.
  * Fix issue with WebSocket connection in case of network issue
    (timeout or connection broken).
  * Fix issue with SSL connection, where latest incoming message
    may be delayed or never processed.
  * Fix possible message lost with publish.single and
    publish.multiple.
- Add paho-mqtt-1.2.2-fix-readme-decoding.patch:
  * Fix error at build when using non-UTF8 locale.
* Sat Mar 18 2017 antoine.belvire@opensuse.org
- Convert package to python singlespec.
* Mon Feb 27 2017 antoine.belvire@opensuse.org
- Initial package: python-paho-mqtt-1.2
